@@ -16,6 +16,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_SCHED_H
+#include <sched.h>
+#endif /* HAVE_SCHED_H */
+#ifdef HAVE_SYS_CPUSET_H
+#include <sys/cpuset.h>
+#endif /* HAVE_SYS_CPUSET_H */
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif /* HAVE_SYSLOG_H */
@@ -174,6 +180,17 @@ log_syslog(int priority, const char *message)
 	log_file(priority, message);
 }
 
+void
+log_only_syslog(int priority, const char *message)
+{
+#ifdef HAVE_SYSLOG_H
+	syslog(priority, "%s", message);
+#else /* !HAVE_SYSLOG_H */
+	/* no syslog, use stderr */
+	log_file(priority, message);
+#endif
+}
+
 void
 log_set_log_function(log_function_type *log_function)
 {
@@ -263,9 +280,9 @@ xalloc(size_t size)
 
 void *
 xmallocarray(size_t num, size_t size)
-{  
+{
         void *result = reallocarray(NULL, num, size);
-   
+
         if (!result) {
                 log_msg(LOG_ERR, "reallocarray failed: %s", strerror(errno));
                 exit(1);
@@ -834,7 +851,7 @@ mktime_from_utc(const struct tm *tm)
    http://www.tsfr.org/~orc/Code/bsd/bsd-current/cksum/crc.c.
    or http://gobsd.com/code/freebsd/usr.bin/cksum/crc.c
    The polynomial is 0x04c11db7L. */
-static u_long crctab[] = {
+static uint32_t crctab[] = {
 	0x0,
 	0x04c11db7, 0x09823b6e, 0x0d4326d9, 0x130476dc, 0x17c56b6b,
 	0x1a864db2, 0x1e475005, 0x2608edb8, 0x22c9f00f, 0x2f8ad6d6,
@@ -1167,20 +1184,35 @@ error(const char *format, ...)
 }
 
 #ifdef HAVE_CPUSET_T
-#if __linux__ || __FreeBSD__
+#if defined(HAVE_SYSCONF) && defined(_SC_NPROCESSORS_CONF)
+/* exists on Linux and FreeBSD */
 int number_of_cpus(void)
 {
 	return (int)sysconf(_SC_NPROCESSORS_CONF);
 }
+#else
+int number_of_cpus(void)
+{
+	return -1;
+}
 #endif
-#if __linux__
+#ifdef __gnu_hurd__
+/* HURD has no sched_setaffinity implementation, but links an always fail,
+ * with a linker error, we print an error when it is used */
+int set_cpu_affinity(cpuset_t *ATTR_UNUSED(set))
+{
+	log_err("sched_setaffinity: not available on this system");
+	return -1;
+}
+#elif defined(HAVE_SCHED_SETAFFINITY)
+/* Linux */
 int set_cpu_affinity(cpuset_t *set)
 {
 	assert(set != NULL);
 	return sched_setaffinity(getpid(), sizeof(*set), set);
 }
-#endif
-#if __FreeBSD__
+#else
+/* FreeBSD */
 int set_cpu_affinity(cpuset_t *set)
 {
 	assert(set != NULL);
